@@ -21,7 +21,7 @@ from grobid_client.models import (
 from grobid_client.types import File, TEI
 from pydantic import Field, BaseModel
 from pymultirole_plugins.v1.converter import ConverterParameters, ConverterBase
-from pymultirole_plugins.v1.schema import Document, Sentence, Boundary, Annotation, Term
+from pymultirole_plugins.v1.schema import Document, Sentence, Boundary, Annotation, Term, AltText
 from starlette.datastructures import UploadFile
 
 # _home = os.path.expanduser('~')
@@ -53,6 +53,9 @@ class GrobidParameters(ConverterParameters):
     citations: bool = Field(
         False, description="Do extract bibliographic references in text"
     )
+    extract_abstract: bool = Field(
+        False, description="Do extract an abstract as altText"
+    )
 
 
 class GrobidConverter(ConverterBase):
@@ -239,6 +242,13 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
             doc.annotations = annotations
         doc.sentences = sentences
         doc.boundaries = boundaries
+        if params.extract_abstract and boundaries:
+            bnames = [k for k in boundaries.keys() if k.lower() != "title"]
+            if bnames:
+                abname = "ABSTRACT" if "ABSTRACT" in bnames else bnames[0]
+                ab = boundaries[abname][0]
+                atext = doc.text[ab.start:ab.end]
+                doc.altTexts = [AltText(name="abstract", text=atext)]
 
 
 def add_references(sentence: TextWithRefs, text_buf: List[str], ref2citations):
